#!/bin/sh

INSTALL_DIR=/etc/protector
PWD_DIR=`pwd`

#
# Check OS type
#
UNAME_EXE=`which uname`
UNAME=`$UNAME_EXE`
if [ $UNAME = "Linux" ]; then
	echo "System is $UNAME"
elif [ $UNAME = "VMkernel" ]; then
	echo "System is $UNAME"
	INSTALL_DIR=/vmfs/volumes/datastore1/protector
else
	echo "OS ERROR: The detected OS is $UNAME, these programs need to run under Linux."
	exit 1
fi

#
# Check user type
#
if [ $UNAME = "Linux" ]; then
	UID_TYPE=`id | sed 's/^uid=\([0-9][0-9]*\).*$/\1/'`
	if [ $UID_TYPE -ne 0 ]; then
		echo "The script must be run by root."
		exit 1
	fi
fi	

#
# Check source files
#
if [ ! -s $PWD_DIR/protector ]; then
	echo "Missing File Error: $PWD_DIR/protector does not exist."
	exit 2
fi

if [ ! -s $PWD_DIR/preoff.sh ]; then
	echo "Missing File Error: $PWD_DIR/preoff.sh does not exist."
	exit 2
fi

#
# Execute installation
#
if [ -s $INSTALL_DIR/protector ]; then
	$INSTALL_DIR/protector -t 2>/dev/null
fi

if [ ! -d $INSTALL_DIR ]; then
    mkdir $INSTALL_DIR
fi

cd $INSTALL_DIR
cp $PWD_DIR/protector $INSTALL_DIR/ 2>/dev/null

if [ $? != 0 ]; then
    echo ""
    echo "Please stop the protector background process and reinstall this."
    echo ""
    exit 0
fi

cp $PWD_DIR/preoff.sh $INSTALL_DIR/ 2>/dev/null

chmod 555 $INSTALL_DIR/protector 2>/dev/null
chmod 555 $INSTALL_DIR/preoff.sh 2>/dev/null

#
# Add start-up 
#
STARTUP=/etc/rc.d/rc.local
SYSOS=`cat /etc/issue | grep 'Ubuntu'`
if [ "$SYSOS" ]; then
    echo "Add start-up for Ubuntu."
    STARTUP=/etc/rc.local
fi

SYSOS=`cat /etc/issue | grep 'Debian'`
if [ "$SYSOS" ]; then
    echo "Add start-up for Debian."
 	STARTUP=/etc/rc.local
fi

SYSOS=`cat /etc/issue | grep 'SUSE'`
if [ "$SYSOS" ]; then
    echo "Add start-up for SUSE."
 	STARTUP=/etc/rc.d/after.local
fi

if [ $UNAME = "VMkernel" ]; then
	echo "Add start-up for VMWare."
	
 	if [ ! -d /etc/rc.local.d ]; then
		STARTUP=/etc/rc.local
	else
		STARTUP=/etc/rc.local.d/local.sh    
	fi
	
	# delete exit 0 at end
	sed -i '/^exit 0/d' $STARTUP
fi

echo "Adding startup command to $STARTUP startup file."
STARTUP_NOW=`grep -n $INSTALL_DIR $STARTUP`
if [ -z "$STARTUP_NOW" ]; then
    echo "$INSTALL_DIR/protector -s &" >> $STARTUP
fi

chmod +x $STARTUP

#
# Start application
#
echo ""
echo "Configure the parameter."
$INSTALL_DIR/protector -c
sync

echo "Installation completed!"
echo ""
echo "Start application... "
$INSTALL_DIR/protector -s &

exit 0
